/*
 * $Id: Host.java 238 2005-08-15 22:26:43Z davidb $
 *
 * Copyright (c) 2005 VeriSign, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

package se.rfc.unbound;

import java.io.IOException;
import java.net.InetAddress;
import java.net.InetSocketAddress;

/**
 * This class represents a destination for DNS messages.
 * 
 * @author davidb
 */
public class Host
{
  private InetSocketAddress mAddr;
  private short             mEDNSVersion = 0;
  private Object            mState;
  
  public Host(String a, String p)
      throws IOException
  {
    int port = Integer.parseInt(p);
    InetAddress addr = InetAddress.getByName(a);

    mAddr = new InetSocketAddress(addr, port);
  }

  public Host(String a)
      throws IOException
  {
    this(a, "53");
  }

  public Host(InetAddress a, int port)
  {
    mAddr = new InetSocketAddress(a, port);
  }

  public Host(InetAddress a)
  {
    this(a, 53);
  }

  public Host(InetSocketAddress addr)
  {
    mAddr = addr;
  }

  /**
   * @return Returns the IP address for this host.
   */
  public InetAddress getAddress()
  {
    return mAddr.getAddress();
  }

  public String getHostAddress()
  {
    return mAddr.getAddress().getHostAddress();
  }

  public InetSocketAddress getSocketAddress()
  {
    return mAddr;
  }

  /**
   * @return Returns the port to send DNS requests to.
   */
  public int getPort()
  {
    return mAddr.getPort();
  }

  public short getEDNSVersion()
  {
    return mEDNSVersion;
  }

  public void setEDNSVersion(int version)
  {
    mEDNSVersion = (short) version;
  }

  public String toString()
  {
    if (getPort() != 53)
    {
      return "<" + getHostAddress() + ":" + getPort() + ">";
    }
    return "<" + getHostAddress() + ">";
  }

  /**
   * Host object may contain an optional opaque "state" object reference. This
   * method returns it.
   * 
   * @return Returns the state object.
   */
  public Object getState()
  {
    return mState;
  }

  /**
   * Host objects may contain an optional opaque "state" object reference.
   * This method sets it.
   * 
   * @param state The state object to set.
   */
  public void setState(Object state)
  {
    mState = state;
  }
}